Public bug reported:
On Neutrino (Vera), synchronous BPMP debugfs population delays probe and fails
with -27 on both sockets.
Backport upstream “firmware: tegra: bpmp: Allow BPMP debugfs population to be
skipped” to provide the opt-out tegra_bpmp.debugfs=0. Debugfs remains enabled
by default.
Native ARM64 64K kernel and modules build passed. In paired traced boots of the
same patched kernel, the opt-out reduced combined BPMP initialization from
16.823 s to 31.890 ms—a 16.791 s reduction—with both devices still bound and no
debugfs initialization failures, thus avoiding the failing initialization path.
** Affects: linux-nvidia-bos (Ubuntu)
Importance: Undecided
Status: New
--
You received this bug notification because you are a member of Ubuntu
Bugs, which is subscribed to Ubuntu.
https://bugs.launchpad.net/bugs/2170236
Title:
BPMP debugfs population significantly delays boot on Vera
To manage notifications about this bug go to:
https://bugs.launchpad.net/ubuntu/+source/linux-nvidia-bos/+bug/2170236/+subscriptions
--
ubuntu-bugs mailing list
[email protected]
https://lists.ubuntu.com/mailman/listinfo/ubuntu-bugs